#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cookie
version: 0.4.1.6
id: cookie-0.4.1.6-97fa5cf54d4ed1e2644dbcebe7255b51
key: cooki_2Eb4iZo39x3Ihl7jVKbtZO
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/snoyberg/cookie
synopsis: HTTP cookie parsing and rendering
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Web.Cookie
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cookie-0.4.1.6
library-dirs: /usr/lib/ghc-7.10.3/site-local/cookie-0.4.1.6
data-dir: /usr/share/arm-linux-ghc-7.10.3/cookie-0.4.1.6
hs-libraries: HScookie-0.4.1.6-2Eb4iZo39x3Ihl7jVKbtZO
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
haddock-interfaces: /usr/share/doc/haskell-cookie/html/cookie.haddock
haddock-html: /usr/share/doc/haskell-cookie/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
